# README

Author: Joel H. Nitta (joelnitta@gmail.com)

Latest update: 2021-05-07

These include raw data files collected during JH Nitta PhD thesis at Harvard
University, 2012-2014 (Moorea CommPhy project). All raw data files were copied
from Moorea CommPhy project folder and set to be read-only. Also includes other
raw data files generated later.

Any code (R scripts) mentioned below can be found at
https://github.com/joelnitta/moorea_filmies

---

### 2012

- `all gametos 10-3.xlsx`: Raw data of desiccation tolerance (DT) test on fern
  gametophytes on Moorea from 2012. Column `Individual` indicates collection
  number. Each measurement was made three times. Data are split across
  worksheets corresponding to desiccation status: `DARK` (before the DT test),
  `DRY` (while in the dry state), `10 MIN` (ca. 10-30 min after re-wetting), `24
  HR`, `48 HR`, `72 HR` each for that many hours after re-wetting. `SUMMARY`
  uses excel formulas to calculate mean recovery rate by individual and time.

- `dt-test-notes-2012.txt`: Additional notes detailing setup for 2012 DT test.

- `hobo`: Contains readouts from Hobo Pro V2 dataloggers for relative humidity
  and temperature inside desiccation chambers for Callistopteris apiifolia NaCl
  treatment. Original Hobo files have extension 'hobo', and data exported to CSV
  have extension 'csv'.

- `Moorea Filmy DT 2 8-26 (version 1).xlsx`: Raw data of DT test data in filmy
  fern sporophytes on Moorea from 2012. Copied from
  /Volumes/Transcend/Projects/Moorea CommPhy/2012 Fieldwork/D-T test/Moorea
  Filmy DT 2 8-26 (version 1).xlsx

- `new 200 m ter gameto.xlsx`: Raw data of DT test on fern gametophytes on
  Moorea from 2012. Same format as all `gametos 10-3.xlsx`, but contains some
  additional samples not in that set.

- `track-it`: Contains data for relative humidity and temperature inside
  desiccation chambers measured with "Track-It" dataloggers, including the
  following:

    - `filmyDT2_LiCl.csv`: Temperature (C) and relative humidity measured inside
      sporophyte desiccation chamber with LiCl as desiccant.

    - `filmyDT2_MgNO3.csv`: Temperature (C) and relative humidity measured
      inside sporophyte desiccation chamber with MgNO3 as desiccant.

    - `filmyDT2_NaCl.csv`: Temperature (C) and relative humidity measured inside
      sporophyte desiccation chamber with NaCl as desiccant.

    - `gameto1_7-14.csv`: Temperature (C) and relative humidity measured inside
      gametophyte desiccation chamber with MgNO3 as desiccant.

    - `gameto2_7-24.csv`: Temperature (C) and relative humidity measured inside
      gametophyte desiccation chamber with MgNO3 as desiccant.

### 2013

- `Filmy Fern DT 1 Dtah, Ckur, Capi.xlsx`: Raw data of DT test data in filmy
  fern sporophytes on Moorea from 2013. Includes data for Didymoglossum
  tahitense, Crepidomanes kurzii, and Callistopteris apiifolia.

- `Filmy Fern DT 2 Pbor.xlsx`: Raw data of DT test data in filmy fern
  sporophytes on Moorea from 2013. Includes data for Polyphelbium borbonicum.

- `Filmy Fern DT 3 Hmul, Hdig.xlsx`: Raw data of DT test data in filmy fern
  sporophytes on Moorea from 2013. Includes data for Hymenophyllum multifidum
  and Hymenophyllum digitatum.

- `Filmy Fern DT 4 Hpol.xlsx`: Raw data of DT test data in filmy fern
  sporophytes on Moorea from 2013. Includes data for Hymenophyllum polyanthos.

- `Filmy Fern DT Set 5 DONE.xlsx`: Raw data of DT test data in filmy fern
  sporophytes on Moorea from 2013. Includes data for Abrodictyum dentatum.

- `Filmy Fern Light Curves 7_26_13.xlsx`: Partial light curve data for filmy
  ferns measured in lab. Contains voucher numbers and / or collection site for
  samples. Downloaded from "Moorea 2013" folder in Google Drive.

- `hobo`: Contains readouts from Hobo Pro V2 dataloggers for relative humidity
  and temperature inside desiccation chambers. Original Hobo files have
  extension 'hobo', and data exported to CSV have extension 'csv'. For
  information on each file, see `hobo_metadata.csv` in `intermediates`.

- `minipam`: Contains raw miniPAM data (files with the *.pam extension) from
  measurements during desiccation tolerance test and light curves, including the
  following:

    - `Abrodictyum_dentatum light curves 7-31-13.pam`: Light curves measured on A. dentatum sporophytes.
    - `Atiati 400m 7-4-13.pam`: Light curves measured at the Atiati 400 m site.
    - `Filmy Fern  light curves 8-1-13.pam`: Light curves of sporophytes measured in the lab.
    - `Filmy Fern  light curves 8-6-13.pam`: Light curves of sporophytes measured in the lab.
    - `Filmy Fern  light curves 8-8-13.pam`: Light curves of sporophytes measured in the lab.
    - `miniPAM SET1 ALL 6-07 to 6-18-13.pam`: Yield measurements for desiccation tolerance test.
    - `miniPAM SET2 ALL 6-18 to 7-2-13.pam`: Yield measurements for desiccation tolerance test.
    - `miniPAM SET3 ALL 7-2 to 7-18-13.pam`: Yield measurements for desiccation tolerance test.
    - `miniPAM SET4 ALL 7-18 to 7-29-13.pam`: Yield measurements for desiccation tolerance test.
    - `miniPAM SET5 ALL 7-31-13 to 8-12-13.pam`: Yield measurements for desiccation tolerance test.
    - `Mouaputa 200m 6-8-13.pam`: Light curves measured in at the Mouaputa 200 m site.
    - `Mouaputa 400m 6-7-13.pam`: Light curves measured in at the Mouaputa 400 m site.
    - `Mouaputa 400m 7-1-13.pam`: Light curves measured in at the Mouaputa 400 m site.
    - `Mouaputa 600m 6-12-13.pam`: Light curves measured in at the Mouaputa 600 m site.
    - `Mouaputa 600m 6-24-13.pam`: Light curves measured in at the Mouaputa 600 m site.
    - `Mouaputa 800m 6-10-13.pam`: Light curves measured in at the Mouaputa 800 m site.
    - `Mouaputa 800m 6-21-13.pam`: Light curves measured in at the Mouaputa 800 m site.
    - `Mouaputa 800m 7-10-13.pam`: Light curves measured in at the Mouaputa 800 m site.
    - `Muaroa 400m 6-19-13.pam`: Light curves measured in at the Muaroa 400 m site.
    - `Muaroa 400m 6-23-13.pam`: Light curves measured in at the Muaroa 400 m site.
    - `Rotui 600m 7-6-13.pam`: Light curves measured in at the Rotui 600 m site.
    - `Rotui 800m 7-8-13.pam`: Light curves measured in at the Rotui 800 m site.
    - `Three Pines 6-30-13.pam`: Light curves measured in at the Three Pines 200 m site.
    - `Three Pines 200m 6-16-13.pam`: Light curves measured in at the Three Pines 200 m site.
    - `Three Pines 200m 6-28-13.pam`: Light curves measured in at the Three Pines 200 m site.
    - `Three Pines 200m 6-29-13.pam`: Light curves measured in at the Three Pines 200 m site.

- `Moorea 2013 gametophyte DT set1.xlsx` through `Moorea 2013 Gameto DT Set 13
  DONE.xlsx`: Results of DT test data in gametophytes. Colummn `gametophytes`
  contains the collection number for each individual gametophyte. Other columns
  include photosynthetic yield and miniPAM memory numbers for measurements prior
  to desiccation (often labeled `light curve yield` and `light curve memory`),
  when dry (`yield in dry state`), 30 minutes after recovery (`yield rewetted`),
  and 24hr, 48hr, and 72hr after recovery. The memory numbers almost all seem to
  be off by 1: to match to the memory in the raw miniPAM data, subtract 1 from
  the memory number. Copied from `Moorea CommPhy/R analyses/data/DT data/Gameto
  Excel 2013/` (originally entered on google drive and downloaded from there).

### 2014

- `filmyDT2014.xlsx`: Raw data of DT test data in filmy fern sporophytes on
  Moorea from 2014. Includes data for *Hymenophyllum pallidum*, *Crepidomanes
  minutum* v2, and *Vandenboschia maxima*.

- `hobo`: Contains readouts from Hobo Pro V2 dataloggers for relative humidity
  and temperature inside desiccation chambers. Original Hobo files have
  extension 'hobo', and data exported to CSV have extension 'csv'. For
  information on each file, see `hobo_metadata.csv` in `intermediates`.

- `dt-test-notes-2014.txt`: Additional notes detailing setup for 2014 DT test.

### intermediates

Files used for cleaning other raw data.

- `gameto_dt_2013_long_fix.xlsx`: Used by `R/clean_sporo_dt_data.R` for
  verifying miniPAM memory numbers in manually entered data vs. PAM files. On
  the `gamet_dt_2013_long_fix` sheet, values in the columns `individual`,
  `file`, `condition`, `yield`, `memory` (original memory value from raw data),
  `control`, `file_order` are exported from R script `R/clean_sporo_dt_data.R`.
  Column `fix` indicates how to shift the original memory value to obtain the
  correct value (i.e., -1 means the correct value is the original memory value
  -1). `manual_mem` indicates a memory value that should replace the original
  memory value. `corrected_mem` indicates the correct value. Columns beginning
  with `pam` are miniPAM times and yields obtained by looking up the corrected
  memory on the `pam_data` sheet (these correspond to raw miniPAM values, and
  were also exported from `R/clean_sporo_dt_data.R`). `pam_diff` shows the
  difference between the manually entered yield value (`yield`) and the value
  looked up from the miniPAM data (`pam_yield`). This should be near zero (less
  than 20). In cases the difference is >20, a note indicates how to resolve the
  discrepancy.

- `lc_outliers`: Outlier data points to be excluded from light curves (CSV
  files) measured with mini-PAM. Each file was generated using the function
  `select_lc_points()` in the `R/clean_lc_data.R` script. Names of files
  indicate the light curve sample. The first column is un-named and includes row
  numbers. Subsequent columns include "etr" (electron transport rate), "par"
  (amount of photosynthetic radiation), "etr_fit" (ETR fit by light-curve
  model), "species" (name of species), "generation" (gametophyte or sporophyte),
  "individual" (individual number within collection), "coll_num" (J.H. Nitta
  collection number), "condition" (condition of specimen at time of measurement;
  lab or field), "date" (date of measurement).

- `logger_metadata.csv`: Contains metadata for dataloggers that were used to
  monitor conditions in desiccation chambers during DT test including serial
  numbers, desiccation salt, sample species, sample generation (sporophyte,
  gametophyte, or mixed), year, and whether to include in final data or not
  (use_status). Used by `R/clean_chamber_data.R`.

- `moorea_filmy_dt_2012_headers.csv`: Used by `R/clean_sporo_dt_data.R` for
  renaming columns in `Moorea Filmy DT 2 8-26 (version 1).xlsx`.

### Other files

- `Fig1.eps`: Image file with photographs of filmy ferns from Moorea, French
  Polynesia. All photographs by J. H. Nitta.

- `ppgi_taxonomy_mod.csv`: Modified version of PPGI (2016) taxonomic system for
  ferns and lycophytes at the genus level and higher, with additional new taxa
  described since 2016 and other small ones that weren't included in PPGI 2016.
  Copied from pacific_ferns project.

- `specimens.csv`: Data of ferns specimens collected by J.H. Nitta in French
  Polynesia, exported from OpenRefine database (text facet country = "French
  Polynesia"). Includes a small number of specimens from other collectors.

### md5 checksums

File names with spaces wrapped in quotes. All paths relative
to the data_raw folder. Checksums are 32-byte MD5 hashes generated with
tools::md5sum() in R.

file md5sum  
"2012/all gametos 10-3.xlsx" 1646dbdf13a61f75ced0bc0872c5c566  
2012/dt-test-notes-2012.txt ec8ae9ed9d1a50c1ac28a8d5af2ddafc  
"2012/hobo/cal api NaCl 2d 2.hobo" 23e38c9f03dbfe919c07f5a9cf89c93c  
"2012/hobo/Cal api NaCl1.hobo" 4a94aefed97ca061e0c2c5b096cf1c82  
2012/hobo/cal_api_NaCl_2d_2.csv fb16abbdb6b832afc5f41ea9bf364d95  
2012/hobo/Cal_api_NaCl1.csv e8254bced308e22c559088f2f135c3b0  
"2012/Moorea Filmy DT 2 8-26 (version 1).xlsx" 8450307f4d59092c0b267dd96be56e7e  
"2012/new 200 m ter gameto.xlsx" 1356706bc2bd592bc1797c3251a226cf  
2012/track-it/filmyDT2_LiCl.csv 307f7d9925a7eb144d68fabeeaa8595f  
2012/track-it/filmyDT2_MgNO3.csv 484608423233a176f0f990d64ec5da3a  
2012/track-it/filmyDT2_NaCl.csv 7481e9d0ac217314e0b97e037ada8d73  
2012/track-it/gameto1_7-14.csv a2c9422a075d30a337d15f5221e71448  
2012/track-it/gameto2_7-24.csv af5065e1eb1f636654563088375c2ce9  
"2013/Filmy Fern DT 1 Dtah, Ckur, Capi.xlsx" 3cba7483e64088239a45cf08686e7e86  
"2013/Filmy Fern DT 2 Pbor.xlsx" 31c56f953f56a09aed48dff09932e46c  
"2013/Filmy Fern DT 3 Hmul, Hdig.xlsx" 46693b49d244d174cc400da55703332a  
"2013/Filmy Fern DT 4 Hpol.xlsx" ecac9c184ee1eaf1ced693965b17fadc  
"2013/Filmy Fern DT Set 5 DONE.xlsx" 795577c2791cc818a7b802c5c7ea0861  
"2013/Filmy Fern Light Curves 7_26_13.xlsx" cf774fb22fc1150a37ed6469e2ca9a66  
"2013/hobo/A._dent._MgNO3_2d 6-16-13.hobo" 0b07b7c80a8a40697f2b67af6d71c18d  
2013/hobo/A._dent._MgNO3_2d_6-16-13.csv 764e4700795552bbe68c1240f8883853  
"2013/hobo/A._dent._NaCl_15d 6-10 to 6-16-13.hobo" 69aa708a9cebd52b1ae33b3d20472e30  
2013/hobo/A._dent._NaCl_15d_6-10_to_6-16-13.csv 73f34f5f1db02956f50743728d85e17e  
"2013/hobo/Filmies Set 1_LiCl_2d.hobo" 291db2e89a584768c17d86bd1b60440e  
"2013/hobo/Filmies Set 1_NaCl_2d.hobo" 790d5e6842c6475ccc1421e9c2c0f884  
"2013/hobo/Filmies_LiCl 7-2-13.hobo" 863aaa6cc8cf73e83bb99378a313090a  
2013/hobo/Filmies_LiCl_7-2-13.csv 533651557585eb3699b673aa7673f84b  
"2013/hobo/Filmies_MgNO3 7-5-13.hobo" c15017af148676b7c431b3f13664370d  
2013/hobo/Filmies_MgNO3_7-5-13.csv 5cafc4335086f22e2e8af75dbc127605  
"2013/hobo/Filmies_Mouaputa 200, 400 gameto_MgNO3_2d.hobo" 30ef60b9c1ff2619e6fb584faafa0942  
2013/hobo/Filmies_Mouaputa_200,_400_gameto_MgNO3_2d.csv adb6d79920ca278379228c087ba969ae  
2013/hobo/Filmies_Set_1_NaCl_2d.csv 5033c83b1bf61727bfa720a40469fec9  
"2013/hobo/Filmy_Set_1_NaCl_15d_6-16_to 7-18.hobo" a6e8587a8f5415e1902f5ffe246313f5  
2013/hobo/Filmy_Set_1_NaCl_15d_6-16_to_7-18.csv 07a6975427e68f57b10873e778dda287  
2013/hobo/Filmy_Set_1,_3_MgNO3_15d_6-16_to_7-2-13.csv f9c8c10558e8f22b81953ae006b120c1  
2013/hobo/Filmy_Set_1,_3_MgNO3_15d_6-16_to_7-2-13.hobo a51ce9dcb8b8944106eb0bcf8ca77fb9  
2013/hobo/Filmy_Set1_15d_NaCl_7-2.csv 9d43733c14732229f919dca034ff8609  
2013/hobo/Filmy_Set1_15d_NaCl_7-2.hobo 4ccad4994b42eaa0d13ca22755208451  
2013/hobo/Gameto_9_DT,_MgNO3_15d_7-5_to7-21-13.csv ba619bf1b83fcba8261c534a411ba0ea  
2013/hobo/Gameto_9_DT,_MgNO3_15d_7-5_to7-21-13.hobo 9b7937e101cefc177f61816e1cb414f7  
"2013/minipam/Abrodictyum_dentatum light curves 7-31-13.pam" 254d8f5f3626b288ef803d04fdce2294  
"2013/minipam/Atiati 400m 7-4-13.pam" 354c3cfbe447b78ea12765725a1a8db7  
"2013/minipam/Filmy Fern  light curves 8-1-13.pam" 5870a062e6d4d36d76ba4205163e1261  
"2013/minipam/Filmy Fern  light curves 8-6-13.pam" 08c2d05485aa50416ee92aa4f0884043  
"2013/minipam/Filmy Fern  light curves 8-8-13.pam" e08cc9eb860bf9ec36c1f650925ecf17  
"2013/minipam/miniPAM SET1 ALL 6-07 to 6-18-13.pam" 0dedc88758e00deb0f310cbca976beef  
"2013/minipam/miniPAM SET2 ALL 6-18 to 7-2-13.pam" 2d4453977fb13823ed28aa849c4bc490  
"2013/minipam/miniPAM SET3 ALL 7-2 to 7-18-13.pam" b1cbf312d1f3edb0e2f0cf5ad43949ff  
"2013/minipam/miniPAM SET4 ALL 7-18 to 7-29-13.pam" 0924b4393fe1fc826348b7965a33c70e  
"2013/minipam/miniPAM SET5 ALL 7-31-13 to 8-12-13.pam" 27fdae6644aaf631c1e63bf5e3f5cbe1  
"2013/minipam/Mouaputa 200m 6-8-13.pam" 35e741990a6ed02a3e1146f0cf6b9cc7  
"2013/minipam/Mouaputa 400m 6-7-13.pam" bd4464f3afcb1874089a050b1f393feb  
"2013/minipam/Mouaputa 400m 7-1-13.pam" f6eefd321adf8e2c4e7e119c4c5f9b95  
"2013/minipam/Mouaputa 600m 6-12-13.pam" 416113191a1ce0b25cf8c915537eec59  
"2013/minipam/Mouaputa 600m 6-24-13.pam" 8356887a303e941160bf29710e007db0  
"2013/minipam/Mouaputa 800m 6-10-13.pam" 4002f09aa86af85c4bcd2ac8e17c4560  
"2013/minipam/Mouaputa 800m 6-21-13.pam" 13bf5ae6c0e0c414650e2c36d4ef64de  
"2013/minipam/Mouaputa 800m 7-10-13.pam" e99766159df6d70b68597f5b217efb2e  
"2013/minipam/Muaroa 400m 6-19-13.pam" 45e064067e52a022a1776a66fafab3ba  
"2013/minipam/Muaroa 400m 6-23-13.pam" cdb5690f64e42fee370ca74583e09b9e  
"2013/minipam/Rotui 600m 7-6-13.pam" 57ef141399ddeb8540719412b0070abf  
"2013/minipam/Rotui 800m 7-8-13.pam" 1b484e3b7bc6599b506c997887bd40ad  
"2013/minipam/Three Pines 200m 6-16-13.pam" 8aa2393a75db8d30f709a8e57b65dd24  
"2013/minipam/Three Pines 200m 6-28-13.pam" 559902432393265f0f5c5cea58379773  
"2013/minipam/Three Pines 200m 6-29-13.pam" 95bbf73fafe79a6c2f1d29b0bc99ac58  
"2013/minipam/Three Pines 6-30-13.pam" d344d9a33debb3637ed5ec96e2d06d37  
"2013/Moorea 2013 Gameto DT Set 10 DONE.xlsx" 4ed106bc1139505b5518bb0bdcaa7cfa  
"2013/Moorea 2013 Gameto DT Set 11 DONE.xlsx" 4a4ef61998773add4a2ff181de82a956  
"2013/Moorea 2013 Gameto DT Set 12.xlsx" 41190b9702a3b68930f4492ab249ad8f  
"2013/Moorea 2013 Gameto DT Set 13 DONE.xlsx" 9dc966b207f88416f24da4a4a3b1f8fb  
"2013/Moorea 2013 Gameto DT Set 2 DONE.xlsx" 477599ca3e2f68ac42460ee44258da2d  
"2013/Moorea 2013 Gameto DT Set 3 DONE.xlsx" b11a038f913a14e559d5b62b03fcc46e  
"2013/Moorea 2013 Gameto DT Set 4 DONE.xlsx" db49b83ccbc7430abdc6eed24ed462b0  
"2013/Moorea 2013 Gameto DT Set 5 DONE.xlsx" cd145f3ac364c6c72a1e37b4435107f1  
"2013/Moorea 2013 Gameto DT Set 6 DONE.xlsx" 45e5e14aa9ae9a37d634afa9448b1a85  
"2013/Moorea 2013 Gameto DT Set 7 DONE.xlsx" f5391ad1aebcbce4b75f5e2fd35b872d  
"2013/Moorea 2013 Gameto DT Set 8 DONE.xlsx" 0d1c89dbb8b2806c347334edbc526a6e  
"2013/Moorea 2013 Gameto DT Set 9 DONE.xlsx" 019811abdcb86cc490476d0ea4e747ee  
"2013/Moorea 2013 gametophyte DT set1.xlsx" 02136b3c072e1b037b1963d8850c67d9  
2014/dt-test-notes-2014.txt be1d7920db212f2ed4fb510543fe8d64  
2014/filmyDT2014.xlsx 68383d6ba890e45076068667080a8a11  
"2014/hobo/LiCl 15d 7-2-14.hobo" b9d04699439b7cf3efcc78a06fbd907f  
2014/hobo/LiCl_15d_7-2-14.csv efb03d370620354ee4e9a820b8022bb6  
"2014/hobo/LiCl_2d 7-8-14.hobo" 08064878883a502bde86fb37b375db06  
2014/hobo/LiCl_2d_7-8-14.csv 6fac2d96a17192d492e701583cecd287  
"2014/hobo/MgNO3 15d 7-2-14.hobo" a70025f8f438b9e7feb0e1baab750cd3  
2014/hobo/MgNO3_15d_7-2-14.csv bb6ac7866453193f7590ef2e67cda8bd  
"2014/hobo/MgNO3_2d 7-8-14.hobo" b0014f58e258934dbf8c5e1ddc023b83  
2014/hobo/MgNO3_2d_7-8-14.csv 41d5c472e06c1acd874e0122c2af6188  
"2014/hobo/NaCl 15d 7-2-14.hobo" 3e6decef4772e372bf210420de4b4678  
2014/hobo/NaCl_15d_7-2-14.csv aa5e94eb76a998da3bdfc605f471635c  
"2014/hobo/NaCl_2d H_pal C_min 7-8-14.hobo" 3482ff5ded1e35a71786aada29b5f877  
2014/hobo/NaCl_2d_H_pal_C_min_7-8-14.csv 0fd467c82284d008ded632fa820c35f3  
"2014/hobo/NaCl_2d_Vmax 7-8-14.hobo" 644c5955e04136cf7e941a14ea679003  
2014/hobo/NaCl_2d_Vmax_7-8-14.csv 36c8ba70fc5bb0d251c59ceef2b81257  
Fig1.eps 85271797c5e060d2864da01f3aa439f1  
intermediates/~$gameto_dt_2013_long_fix.xlsx d658e07eda73c3f28a115b3ce4c09b0c  
intermediates/gameto_dt_2013_long_fix.xlsx 10ffb28d6ecef5a83bc6b7f9712fa104  
intermediates/lc_outliers/A_dentatum_gametophyte_1_2930_field_2013-07-06.csv 2ec47d055551aa7ee581bae6bde267ce  
intermediates/lc_outliers/A_dentatum_gametophyte_1_3004_field_2013-07-10.csv a0dc60e03723b69c4ca4836a81f482eb  
intermediates/lc_outliers/A_dentatum_sporophyte_6_NA_lab_2013-07-31.csv 8fdde839f8fdd020ca3ffc29f2a16ae7  
intermediates/lc_outliers/C_apiifolia_gametophyte_1_2479_field_2013-06-10.csv a3ac523f0f617c5b84e6624236030aef  
intermediates/lc_outliers/C_apiifolia_gametophyte_1_2480_field_2013-06-10.csv 7bb14f5f5205958f0d648ab4c38445d1  
intermediates/lc_outliers/C_apiifolia_gametophyte_1_2481_field_2013-06-10.csv edfce49e09fcdab1fddb5b4877e55886  
intermediates/lc_outliers/C_apiifolia_gametophyte_1_2484_field_2013-06-10.csv 8860f9c4381b063e97140fb173774372  
intermediates/lc_outliers/C_apiifolia_gametophyte_1_2489_field_2013-06-10.csv ac99a93d2a09cabffeac8bc002fb8173  
intermediates/lc_outliers/C_apiifolia_gametophyte_1_3009_field_2013-07-10.csv 0e2d13ef7b414dbda76f9cf295b02208  
intermediates/lc_outliers/C_apiifolia_gametophyte_2_2421_field_2013-06-07.csv d7c0783822711b8fe8a7c0e32103c77a  
intermediates/lc_outliers/C_apiifolia_gametophyte_3_2421_field_2013-06-07.csv 23cdee20e9104a2865b21f335bc2a1a3  
intermediates/lc_outliers/C_apiifolia_sporophyte_1_NA_field_2013-06-21.csv 917bb298b0f444fc20ad8573606e8ea0  
intermediates/lc_outliers/C_apiifolia_sporophyte_2_NA_field_2013-06-21.csv 356fab9d0176c4a22832d6466f3a9a4b  
intermediates/lc_outliers/C_apiifolia_sporophyte_3_NA_field_2013-06-21.csv b69a360764b170483e4fad219b3956cf  
intermediates/lc_outliers/C_humile_sporophyte_2_NA_field_2013-06-23.csv a169cf480a405cef4bb4306e37b51333  
intermediates/lc_outliers/C_kurzii_sporophyte_1_NA_field_2013-06-16.csv 38ec2fd8dcc91f1b5686082d3ac60b58  
intermediates/lc_outliers/C_kurzii_sporophyte_2_NA_field_2013-06-16.csv 7533e765c9880e88751d1b5b96677466  
intermediates/lc_outliers/C_kurzii_sporophyte_3_NA_field_2013-06-16.csv ce818a1b7a34ec03df76a009f128a799  
intermediates/lc_outliers/C_kurzii_sporophyte_7_NA_lab_2013-08-06.csv aae53241209ec468aaf9d099c547d4db  
intermediates/lc_outliers/C_minutum1_gametophyte_1_2941_field_2013-07-06.csv 08a17dac5bb8d07fa6de87f68c40dd66  
intermediates/lc_outliers/D_tahitense_sporophyte_2_NA_field_2013-06-16.csv 383f97c3b24046888da639ed3955ce0f  
intermediates/lc_outliers/H_braithwaitei_sporophyte_1_3171_lab_2013-08-06.csv cd61da641aa781f5768fd6cb8d657ae9  
intermediates/lc_outliers/H_braithwaitei_sporophyte_2_3171_lab_2013-08-06.csv 9a72a6521944687f18ba9ff11153eaea  
intermediates/lc_outliers/H_braithwaitei_sporophyte_5_3171_lab_2013-08-06.csv b5d523da1532f669faa029404594f374  
intermediates/lc_outliers/H_digitatum_gametophyte_1_2538_field_2013-06-12.csv 959975a55ced0aba4212ad92e9422644  
intermediates/lc_outliers/H_digitatum_gametophyte_1_2675_field_2013-06-19.csv 37fc8010b246c04c4683b544761c6cbb  
intermediates/lc_outliers/H_digitatum_gametophyte_1_2938_field_2013-07-06.csv 6a2851b1d1c5ff4c711828bf338ac2db  
intermediates/lc_outliers/H_digitatum_gametophyte_1_2942_field_2013-07-06.csv d044a9455347305ed7c50c5f4be92cdc  
intermediates/lc_outliers/H_digitatum_sporophyte_1_NA_field_2013-06-12.csv 89e42a20325ef257e14f67512f7d0b6a  
intermediates/lc_outliers/H_multifidum_sporophyte_9_3174_lab_2013-08-01.csv 2a037f8965bf830805b114667b60164d  
intermediates/lc_outliers/H_polyanthos_gametophyte_1_2497_field_2013-06-10.csv b3c78879649658b1b3bf3fb4f15473ec  
intermediates/lc_outliers/H_polyanthos_gametophyte_1_2498_field_2013-06-10.csv 96b9ee196ba51ada836782268133f519  
intermediates/lc_outliers/H_polyanthos_gametophyte_1_2532_field_2013-06-12.csv 3ae1a083de547cd6c779ffa7d52d9366  
intermediates/lc_outliers/H_polyanthos_gametophyte_1_2535_field_2013-06-12.csv 77f29a3eb6d558c31bd21bdcb2a794ea  
intermediates/lc_outliers/H_polyanthos_gametophyte_1_2547_field_2013-06-12.csv f46763e9da69514765905b20712621a2  
intermediates/lc_outliers/H_polyanthos_gametophyte_1_2935_field_2013-07-06.csv edea2444db84287a0406ea78fc8b511e  
intermediates/lc_outliers/P_borbonicum_gametophyte_1_3013_field_2013-07-10.csv 3f8ecf36f1be4e2d9ecdf3ecb7d8317c  
intermediates/lc_outliers/P_borbonicum_sporophyte_3_NA_field_2013-06-10.csv 438accff6becb481f9eabab22007c1df  
intermediates/lc_outliers/P_endlicherianum_gametophyte_1_2458_field_2013-06-08.csv 5cb6b7bbebc314165b39bb8cdf448e1b  
intermediates/lc_outliers/P_endlicherianum_gametophyte_1_2462_field_2013-06-08.csv e2f37187e7ba045b1aeaaf21dfd60246  
intermediates/lc_outliers/P_endlicherianum_gametophyte_1_2586_field_2013-06-16.csv 5174c19abeca76dd4bac99b8b82e1513  
intermediates/logger_metadata.csv 6ac58e4340c296d98ef24ef0e87a21c1  
intermediates/moorea_filmy_dt_2012_headers.csv a031b8945b34b11d74a475c3c2cf8d33  
intermediates/sporo_dt_long_fix.xlsx 6bb7cacb458ac22c825394d876e00b0c  
ppgi_taxonomy_mod.csv 7769f748b14d5f7ff40ea886c888cc67  
specimens.csv b79c14a770fe280dc7f3221eecd2f2ef  
